@@ -1,9 +1,11 @@
-""" 
+"""
 Basic example of scraping pipeline using SmartScraper
 """
 
 import os
+
 from dotenv import load_dotenv
+
 from scrapegraphai.graphs import SmartScraperGraph
 from scrapegraphai.utils import prettify_exec_info
 
@@ -19,9 +21,9 @@ openai_key = os.getenv("OPENAI_APIKEY")
 graph_config = {
     "llm": {
         "api_key": openai_key,
-        "model": "gpt-3.5-turbo",
+        "model": "openai/gpt-3.5-turbo",
     },
-    "caching": True
+    "caching": True,
 }
 
 # ************************************************
@@ -32,7 +34,7 @@ smart_scraper_graph = SmartScraperGraph(
     prompt="List me all the projects with their description.",
     # also accepts a string with the already downloaded HTML code
     source="https://perinim.github.io/projects/",
-    config=graph_config
+    config=graph_config,
 )
 
 result = smart_scraper_graph.run()
@@ -43,4 +45,4 @@ print(result)
 # ************************************************
 
 graph_exec_info = smart_scraper_graph.get_execution_info()
-print(prettify_exec_info(graph_exec_info))
\ No newline at end of file
+print(prettify_exec_info(graph_exec_info))
