@@ -3,28 +3,34 @@ Example of Search Graph
 """
 
 import os
-from dotenv import load_dotenv
-from scrapegraphai.graphs import SearchGraph
-from langchain_core.pydantic_v1 import BaseModel, Field
 from typing import List
+
+from dotenv import load_dotenv
+from pydantic import BaseModel, Field
+
+from scrapegraphai.graphs import SearchGraph
+
 load_dotenv()
 
+
 # ************************************************
 # Define the configuration for the graph
 # ************************************************
 class CeoName(BaseModel):
     ceo_name: str = Field(description="The name and surname of the ceo")
 
+
 class Ceos(BaseModel):
     names: List[CeoName]
 
+
 openai_key = os.getenv("OPENAI_APIKEY")
 
 graph_config = {
     "llm": {
         "api_key": openai_key,
-        "model": "gpt-4o",
-        },
+        "model": "openai/gpt-4o",
+    },
     "max_results": 2,
     "verbose": True,
 }
@@ -34,8 +40,8 @@ graph_config = {
 # ************************************************
 
 search_graph = SearchGraph(
-    prompt=f"Who is the ceo of Appke?",
-    schema = Ceos,
+    prompt="Who is the ceo of Appke?",
+    schema=Ceos,
     config=graph_config,
 )
 
