@@ -1,23 +1,22 @@
-""" 
+"""
 JSONScraperMultiGraph Module
 """
 
 from copy import deepcopy
-from typing import List, Optional
+from typing import List, Optional, Type
+
 from pydantic import BaseModel
 
-from .base_graph import BaseGraph
-from .abstract_graph import AbstractGraph
-from .json_scraper_graph import JSONScraperGraph
-from ..nodes import (
-    GraphIteratorNode,
-    MergeAnswersNode
-)
+from ..nodes import GraphIteratorNode, MergeAnswersNode
 from ..utils.copy import safe_deepcopy
+from .abstract_graph import AbstractGraph
+from .base_graph import BaseGraph
+from .json_scraper_graph import JSONScraperGraph
+
 
 class JSONScraperMultiGraph(AbstractGraph):
-    """ 
-    JSONScraperMultiGraph is a scraping pipeline that scrapes a 
+    """
+    JSONScraperMultiGraph is a scraping pipeline that scrapes a
     list of URLs and generates answers to a given prompt.
     It only requires a user prompt and a list of URLs.
 
@@ -38,17 +37,19 @@ class JSONScraperMultiGraph(AbstractGraph):
     Example:
         >>> search_graph = MultipleSearchGraph(
         ...     "What is Chioggia famous for?",
-        ...     {"llm": {"model": "gpt-3.5-turbo"}}
+        ...     {"llm": {"model": "openai/gpt-3.5-turbo"}}
         ... )
         >>> result = search_graph.run()
     """
 
-    def __init__(self, prompt: str, source: List[str], config: dict, schema: Optional[BaseModel] = None):
-
-        self.max_results = config.get("max_results", 3)
-
+    def __init__(
+        self,
+        prompt: str,
+        source: List[str],
+        config: dict,
+        schema: Optional[Type[BaseModel]] = None,
+    ):
         self.copy_config = safe_deepcopy(config)
-
         self.copy_schema = deepcopy(schema)
 
         super().__init__(prompt, config, source, schema)
@@ -61,36 +62,20 @@ class JSONScraperMultiGraph(AbstractGraph):
             BaseGraph: A graph instance representing the web scraping and searching workflow.
         """
 
-        # ************************************************
-        # Create a JSONScraperGraph instance
-        # ************************************************
-
-        smart_scraper_instance = JSONScraperGraph(
-            prompt="",
-            source="",
-            config=self.copy_config,
-            schema=self.copy_schema
-        )
-
-        # ************************************************
-        # Define the graph nodes
-        # ************************************************
-
         graph_iterator_node = GraphIteratorNode(
             input="user_prompt & jsons",
             output=["results"],
             node_config={
-                "graph_instance": smart_scraper_instance,
-            }
+                "graph_instance": JSONScraperGraph,
+                "scraper_config": self.copy_config,
+            },
+            schema=self.copy_schema,
         )
 
         merge_answers_node = MergeAnswersNode(
             input="user_prompt & results",
             output=["answer"],
-            node_config={
-                "llm_model": self.llm_model,
-                "schema": self.schema
-            }
+            node_config={"llm_model": self.llm_model, "schema": self.copy_schema},
         )
 
         return BaseGraph(
@@ -102,7 +87,7 @@ class JSONScraperMultiGraph(AbstractGraph):
                 (graph_iterator_node, merge_answers_node),
             ],
             entry_point=graph_iterator_node,
-            graph_name=self.__class__.__name__
+            graph_name=self.__class__.__name__,
         )
 
     def run(self) -> str:
@@ -112,6 +97,7 @@ class JSONScraperMultiGraph(AbstractGraph):
         Returns:
             str: The answer to the prompt.
         """
+
         inputs = {"user_prompt": self.prompt, "jsons": self.source}
         self.final_state, self.execution_info = self.graph.execute(inputs)
 
