@@ -1,24 +1,22 @@
-""" 
+"""
 ScriptCreatorMultiGraph Module
 """
 
-from typing import List, Optional
+from copy import deepcopy
+from typing import List, Optional, Type
 
 from pydantic import BaseModel
 
-from .base_graph import BaseGraph
+from ..nodes import GraphIteratorNode, MergeGeneratedScriptsNode
+from ..utils.copy import safe_deepcopy
 from .abstract_graph import AbstractGraph
+from .base_graph import BaseGraph
 from .script_creator_graph import ScriptCreatorGraph
 
-from ..nodes import (
-    GraphIteratorNode,
-    MergeGeneratedScriptsNode
-)
-from ..utils.copy import safe_deepcopy
 
 class ScriptCreatorMultiGraph(AbstractGraph):
-    """ 
-    ScriptCreatorMultiGraph is a scraping pipeline that scrapes a list 
+    """
+    ScriptCreatorMultiGraph is a scraping pipeline that scrapes a list
     of URLs generating web scraping scripts.
     It only requires a user prompt and a list of URLs.
     Attributes:
@@ -37,18 +35,21 @@ class ScriptCreatorMultiGraph(AbstractGraph):
         >>> script_graph = ScriptCreatorMultiGraph(
         ...     "What is Chioggia famous for?",
         ...     source=[],
-        ...     config={"llm": {"model": "gpt-3.5-turbo"}}
+        ...     config={"llm": {"model": "openai/gpt-3.5-turbo"}}
         ...     schema={}
         ... )
         >>> result = script_graph.run()
     """
 
-    def __init__(self, prompt: str, source: List[str], config: dict, schema: Optional[BaseModel] = None):
-
-        self.max_results = config.get("max_results", 3)
-
+    def __init__(
+        self,
+        prompt: str,
+        source: List[str],
+        config: dict,
+        schema: Optional[Type[BaseModel]] = None,
+    ):
         self.copy_config = safe_deepcopy(config)
-
+        self.copy_schema = deepcopy(schema)
         super().__init__(prompt, config, source, schema)
 
     def _create_graph(self) -> BaseGraph:
@@ -58,36 +59,20 @@ class ScriptCreatorMultiGraph(AbstractGraph):
             BaseGraph: A graph instance representing the web scraping and searching workflow.
         """
 
-        # ************************************************
-        # Create a ScriptCreatorGraph instance
-        # ************************************************
-
-        script_generator_instance = ScriptCreatorGraph(
-            prompt="",
-            source="",
-            config=self.copy_config,
-            schema=self.schema
-        )
-
-        # ************************************************
-        # Define the graph nodes
-        # ************************************************
-
         graph_iterator_node = GraphIteratorNode(
             input="user_prompt & urls",
             output=["scripts"],
             node_config={
-                "graph_instance": script_generator_instance,
-            }
+                "graph_instance": ScriptCreatorGraph,
+                "scraper_config": self.copy_config,
+            },
+            schema=self.copy_schema,
         )
 
         merge_scripts_node = MergeGeneratedScriptsNode(
             input="user_prompt & scripts",
             output=["merged_script"],
-            node_config={
-                "llm_model": self.llm_model,
-                "schema": self.schema
-            }
+            node_config={"llm_model": self.llm_model, "schema": self.schema},
         )
 
         return BaseGraph(
@@ -99,7 +84,7 @@ class ScriptCreatorMultiGraph(AbstractGraph):
                 (graph_iterator_node, merge_scripts_node),
             ],
             entry_point=graph_iterator_node,
-            graph_name=self.__class__.__name__
+            graph_name=self.__class__.__name__,
         )
 
     def run(self) -> str:
@@ -108,6 +93,7 @@ class ScriptCreatorMultiGraph(AbstractGraph):
         Returns:
             str: The answer to the prompt.
         """
+
         inputs = {"user_prompt": self.prompt, "urls": self.source}
         self.final_state, self.execution_info = self.graph.execute(inputs)
         return self.final_state.get("merged_script", "Failed to generate the script.")
