@@ -1,14 +1,19 @@
-""" SearchLinkGraph Module """
-from typing import Optional
-import logging
-from pydantic import BaseModel
-from .base_graph import BaseGraph
-from .abstract_graph import AbstractGraph
-from ..nodes import ( FetchNode, ParseNode, SearchLinkNode )
+"""
+SearchLinkGraph Module
+"""
 
-class SearchLinkGraph(AbstractGraph): 
-    """ 
-    SearchLinkGraph is a scraping pipeline that automates the process of 
+from typing import Optional, Type
+
+from pydantic import BaseModel
+
+from ..nodes import FetchNode, SearchLinkNode, SearchLinksWithContext
+from .abstract_graph import AbstractGraph
+from .base_graph import BaseGraph
+
+
+class SearchLinkGraph(AbstractGraph):
+    """
+    SearchLinkGraph is a scraping pipeline that automates the process of
     extracting information from web pages using a natural language model
     to interpret and answer prompts.
 
@@ -18,7 +23,7 @@ class SearchLinkGraph(AbstractGraph):
         config (dict): Configuration parameters for the graph.
         schema (BaseModel): The schema for the graph output.
         llm_model: An instance of a language model client, configured for generating answers.
-        embedder_model: An instance of an embedding model client, 
+        embedder_model: An instance of an embedding model client,
         configured for generating embeddings.
         verbose (bool): A flag indicating whether to show print statements during execution.
         headless (bool): A flag indicating whether to run the graph in headless mode.
@@ -28,16 +33,12 @@ class SearchLinkGraph(AbstractGraph):
         config (dict): Configuration parameters for the graph.
         schema (BaseModel, optional): The schema for the graph output. Defaults to None.
 
-    Example:
-        >>> smart_scraper = SearchLinkGraph(
-        ...     "List me all the attractions in Chioggia.",
-        ...     "https://en.wikipedia.org/wiki/Chioggia",
-        ...     {"llm": {"model": "gpt-3.5-turbo"}}
-        ... )
-        >>> result = smart_scraper.run()
+
     """
 
-    def __init__(self, source: str, config: dict, schema: Optional[BaseModel] = None):
+    def __init__(
+        self, source: str, config: dict, schema: Optional[Type[BaseModel]] = None
+    ):
         super().__init__("", config, source, schema)
 
         self.input_key = "url" if source.startswith("http") else "local_dir"
@@ -52,44 +53,40 @@ class SearchLinkGraph(AbstractGraph):
 
         fetch_node = FetchNode(
             input="url| local_dir",
-            output=["doc", "link_urls", "img_urls"],
+            output=["doc"],
             node_config={
-                "llm_model": self.llm_model,
                 "force": self.config.get("force", False),
                 "cut": self.config.get("cut", True),
                 "loader_kwargs": self.config.get("loader_kwargs", {}),
-            }
-        )
-        parse_node = ParseNode(
-            input="doc",
-            output=["parsed_doc"],
-            node_config={
-                "chunk_size": self.model_token
-            }
-        )
-        search_link_node = SearchLinkNode(
-            input="doc",
-            output=["parsed_doc"],
-            node_config={
-                "llm_model": self.llm_model,
-                "chunk_size": self.model_token,
-                "filter_links": self.config.get("filter_links", None),
-                "filter_config": self.config.get("filter_config", None)
-            }
+                "storage_state": self.config.get("storage_state"),
+            },
         )
 
+        if self.config.get("llm_style") == (True, None):
+            search_link_node = SearchLinksWithContext(
+                input="doc",
+                output=["parsed_doc"],
+                node_config={
+                    "llm_model": self.llm_model,
+                    "chunk_size": self.model_token,
+                },
+            )
+        else:
+            search_link_node = SearchLinkNode(
+                input="doc",
+                output=["parsed_doc"],
+                node_config={
+                    "chunk_size": self.model_token,
+                    "filter_links": True,
+                    "filter_config": self.config.get("filter_config", {}),
+                },
+            )
+
         return BaseGraph(
-            nodes=[
-                fetch_node,
-                parse_node,
-                search_link_node
-            ],
-            edges=[
-                (fetch_node, parse_node),
-                (parse_node, search_link_node)
-            ],
+            nodes=[fetch_node, search_link_node],
+            edges=[(fetch_node, search_link_node)],
             entry_point=fetch_node,
-            graph_name=self.__class__.__name__
+            graph_name=self.__class__.__name__,
         )
 
     def run(self) -> str:
