@@ -1,26 +1,21 @@
-""" 
+"""
 SpeechGraph Module
 """
 
-from typing import Optional
+from typing import Optional, Type
+
 from pydantic import BaseModel
 
-from .base_graph import BaseGraph
-from .abstract_graph import AbstractGraph
-
-from ..nodes import (
-    FetchNode,
-    ParseNode,
-    GenerateAnswerNode,
-    TextToSpeechNode,
-)
-
-from ..utils.save_audio_from_bytes import save_audio_from_bytes
 from ..models import OpenAITextToSpeech
+from ..nodes import FetchNode, GenerateAnswerNode, ParseNode, TextToSpeechNode
+from ..utils.save_audio_from_bytes import save_audio_from_bytes
+from .abstract_graph import AbstractGraph
+from .base_graph import BaseGraph
+
 
 class SpeechGraph(AbstractGraph):
     """
-    SpeechyGraph is a scraping pipeline that scrapes the web, provide an answer 
+    SpeechyGraph is a scraping pipeline that scrapes the web, provide an answer
     to a given prompt, and generate an audio file.
 
     Attributes:
@@ -29,7 +24,8 @@ class SpeechGraph(AbstractGraph):
         config (dict): Configuration parameters for the graph.
         schema (BaseModel): The schema for the graph output.
         llm_model: An instance of a language model client, configured for generating answers.
-        embedder_model: An instance of an embedding model client, configured for generating embeddings.
+        embedder_model: An instance of an embedding model clienta
+                        configured for generating embeddings.
         verbose (bool): A flag indicating whether to show print statements during execution.
         headless (bool): A flag indicating whether to run the graph in headless mode.
         model_token (int): The token limit for the language model.
@@ -44,10 +40,16 @@ class SpeechGraph(AbstractGraph):
         >>> speech_graph = SpeechGraph(
         ...     "List me all the attractions in Chioggia and generate an audio summary.",
         ...     "https://en.wikipedia.org/wiki/Chioggia",
-        ...     {"llm": {"model": "gpt-3.5-turbo"}}
+        ...     {"llm": {"model": "openai/gpt-3.5-turbo"}}
     """
 
-    def __init__(self, prompt: str, source: str, config: dict, schema: Optional[BaseModel] = None):
+    def __init__(
+        self,
+        prompt: str,
+        source: str,
+        config: dict,
+        schema: Optional[Type[BaseModel]] = None,
+    ):
         super().__init__(prompt, config, source, schema)
 
         self.input_key = "url" if source.startswith("http") else "local_dir"
@@ -60,48 +62,39 @@ class SpeechGraph(AbstractGraph):
             BaseGraph: A graph instance representing the web scraping and audio generation workflow.
         """
 
-        fetch_node = FetchNode(
-            input="url | local_dir",
-            output=["doc", "link_urls", "img_urls"]
-        )
+        fetch_node = FetchNode(input="url | local_dir", output=["doc"])
+
         parse_node = ParseNode(
             input="doc",
             output=["parsed_doc"],
-            node_config={
-                "chunk_size": self.model_token
-            }
+            node_config={"chunk_size": self.model_token, "llm_model": self.llm_model},
         )
+
         generate_answer_node = GenerateAnswerNode(
             input="user_prompt & (relevant_chunks | parsed_doc | doc)",
             output=["answer"],
             node_config={
                 "llm_model": self.llm_model,
                 "additional_info": self.config.get("additional_info"),
-                "schema": self.schema
-            }
+                "schema": self.schema,
+            },
         )
+
         text_to_speech_node = TextToSpeechNode(
             input="answer",
             output=["audio"],
-            node_config={
-                "tts_model": OpenAITextToSpeech(self.config["tts_model"])
-            }
+            node_config={"tts_model": OpenAITextToSpeech(self.config["tts_model"])},
         )
 
         return BaseGraph(
-            nodes=[
-                fetch_node,
-                parse_node,
-                generate_answer_node,
-                text_to_speech_node
-            ],
+            nodes=[fetch_node, parse_node, generate_answer_node, text_to_speech_node],
             edges=[
                 (fetch_node, parse_node),
                 (parse_node, generate_answer_node),
-                (generate_answer_node, text_to_speech_node)
+                (generate_answer_node, text_to_speech_node),
             ],
             entry_point=fetch_node,
-            graph_name=self.__class__.__name__
+            graph_name=self.__class__.__name__,
         )
 
     def run(self) -> str:
@@ -118,8 +111,7 @@ class SpeechGraph(AbstractGraph):
         audio = self.final_state.get("audio", None)
         if not audio:
             raise ValueError("No audio generated from the text.")
-        save_audio_from_bytes(audio, self.config.get(
-            "output_path", "output.mp3"))
+        save_audio_from_bytes(audio, self.config.get("output_path", "output.mp3"))
         print(f"Audio saved to {self.config.get('output_path', 'output.mp3')}")
 
         return self.final_state.get("answer", "No answer found.")
