@@ -2,16 +2,14 @@
 XMLScraperGraph Module
 """
 
-from typing import Optional
+from typing import Optional, Type
+
 from pydantic import BaseModel
 
-from .base_graph import BaseGraph
+from ..nodes import FetchNode, GenerateAnswerNode
 from .abstract_graph import AbstractGraph
+from .base_graph import BaseGraph
 
-from ..nodes import (
-    FetchNode,
-    GenerateAnswerNode
-)
 
 class XMLScraperGraph(AbstractGraph):
     """
@@ -24,7 +22,7 @@ class XMLScraperGraph(AbstractGraph):
         config (dict): Configuration parameters for the graph.
         schema (BaseModel): The schema for the graph output.
         llm_model: An instance of a language model client, configured for generating answers.
-        embedder_model: An instance of an embedding model client, 
+        embedder_model: An instance of an embedding model client,
         configured for generating embeddings.
         verbose (bool): A flag indicating whether to show print statements during execution.
         headless (bool): A flag indicating whether to run the graph in headless mode.
@@ -40,12 +38,18 @@ class XMLScraperGraph(AbstractGraph):
         >>> xml_scraper = XMLScraperGraph(
         ...     "List me all the attractions in Chioggia.",
         ...     "data/chioggia.xml",
-        ...     {"llm": {"model": "gpt-3.5-turbo"}}
+        ...     {"llm": {"model": "openai/gpt-3.5-turbo"}}
         ... )
         >>> result = xml_scraper.run()
     """
 
-    def __init__(self, prompt: str, source: str, config: dict, schema: Optional[BaseModel] = None):
+    def __init__(
+        self,
+        prompt: str,
+        source: str,
+        config: dict,
+        schema: Optional[Type[BaseModel]] = None,
+    ):
         super().__init__(prompt, config, source, schema)
 
         self.input_key = "xml" if source.endswith("xml") else "xml_dir"
@@ -58,10 +62,7 @@ class XMLScraperGraph(AbstractGraph):
             BaseGraph: A graph instance representing the web scraping workflow.
         """
 
-        fetch_node = FetchNode(
-            input="xml | xml_dir",
-            output=["doc", "link_urls", "img_urls"]
-        )
+        fetch_node = FetchNode(input="xml | xml_dir", output=["doc"])
 
         generate_answer_node = GenerateAnswerNode(
             input="user_prompt & (relevant_chunks | doc)",
@@ -69,8 +70,8 @@ class XMLScraperGraph(AbstractGraph):
             node_config={
                 "llm_model": self.llm_model,
                 "additional_info": self.config.get("additional_info"),
-                "schema": self.schema
-            }
+                "schema": self.schema,
+            },
         )
 
         return BaseGraph(
@@ -78,11 +79,9 @@ class XMLScraperGraph(AbstractGraph):
                 fetch_node,
                 generate_answer_node,
             ],
-            edges=[
-                (fetch_node, generate_answer_node)
-            ],
+            edges=[(fetch_node, generate_answer_node)],
             entry_point=fetch_node,
-            graph_name=self.__class__.__name__
+            graph_name=self.__class__.__name__,
         )
 
     def run(self) -> str:
