@@ -1,24 +1,22 @@
-""" 
+"""
 XMLScraperMultiGraph Module
 """
 
 from copy import deepcopy
-from typing import List, Optional
+from typing import List, Optional, Type
+
 from pydantic import BaseModel
 
-from .base_graph import BaseGraph
+from ..nodes import GraphIteratorNode, MergeAnswersNode
+from ..utils.copy import safe_deepcopy
 from .abstract_graph import AbstractGraph
+from .base_graph import BaseGraph
 from .xml_scraper_graph import XMLScraperGraph
 
-from ..nodes import (
-    GraphIteratorNode,
-    MergeAnswersNode
-)
-from ..utils.copy import safe_deepcopy
 
 class XMLScraperMultiGraph(AbstractGraph):
-    """ 
-    XMLScraperMultiGraph is a scraping pipeline that scrapes a list of URLs and 
+    """
+    XMLScraperMultiGraph is a scraping pipeline that scrapes a list of URLs and
     generates answers to a given prompt.
     It only requires a user prompt and a list of URLs.
 
@@ -39,18 +37,20 @@ class XMLScraperMultiGraph(AbstractGraph):
     Example:
         >>> search_graph = MultipleSearchGraph(
         ...     "What is Chioggia famous for?",
-        ...     {"llm": {"model": "gpt-3.5-turbo"}}
+        ...     {"llm": {"model": "openai/gpt-3.5-turbo"}}
         ... )
         >>> result = search_graph.run()
     """
 
-    def __init__(self, prompt: str, source: List[str], 
-                 config: dict, schema: Optional[BaseModel] = None):
-
+    def __init__(
+        self,
+        prompt: str,
+        source: List[str],
+        config: dict,
+        schema: Optional[Type[BaseModel]] = None,
+    ):
         self.copy_config = safe_deepcopy(config)
-
         self.copy_schema = deepcopy(schema)
-
         super().__init__(prompt, config, source, schema)
 
     def _create_graph(self) -> BaseGraph:
@@ -60,37 +60,20 @@ class XMLScraperMultiGraph(AbstractGraph):
         Returns:
             BaseGraph: A graph instance representing the web scraping and searching workflow.
         """
-
-        # ************************************************
-        # Create a XMLScraperGraph instance
-        # ************************************************
-
-        smart_scraper_instance = XMLScraperGraph(
-            prompt="",
-            source="",
-            config=self.copy_config,
-            schema=self.copy_schema
-        )
-
-        # ************************************************
-        # Define the graph nodes
-        # ************************************************
-
         graph_iterator_node = GraphIteratorNode(
             input="user_prompt & jsons",
             output=["results"],
             node_config={
-                "graph_instance": smart_scraper_instance,
-            }
+                "graph_instance": XMLScraperGraph,
+                "scaper_config": self.copy_config,
+            },
+            schema=self.copy_schema,
         )
 
         merge_answers_node = MergeAnswersNode(
             input="user_prompt & results",
             output=["answer"],
-            node_config={
-                "llm_model": self.llm_model,
-                "schema": self.schema
-            }
+            node_config={"llm_model": self.llm_model, "schema": self.copy_schema},
         )
 
         return BaseGraph(
@@ -102,7 +85,7 @@ class XMLScraperMultiGraph(AbstractGraph):
                 (graph_iterator_node, merge_answers_node),
             ],
             entry_point=graph_iterator_node,
-            graph_name=self.__class__.__name__
+            graph_name=self.__class__.__name__,
         )
 
     def run(self) -> str:
@@ -112,6 +95,7 @@ class XMLScraperMultiGraph(AbstractGraph):
         Returns:
             str: The answer to the prompt.
         """
+
         inputs = {"user_prompt": self.prompt, "xmls": self.source}
         self.final_state, self.execution_info = self.graph.execute(inputs)
 
