@@ -1,12 +1,14 @@
-""" 
+"""
 Module for mapping the models in ai agents
 """
 
 robots_dictionary = {
     "gpt-3.5-turbo": ["GPTBot", "ChatGPT-user"],
     "gpt-4-turbo": ["GPTBot", "ChatGPT-user"],
+    "gpt-4o": ["GPTBot", "ChatGPT-user"],
+    "gpt-4o-mini": ["GPTBot", "ChatGPT-user"],
     "claude": ["Claude-Web", "ClaudeBot"],
     "perplexity": "PerplexityBot",
     "cohere": "cohere-ai",
-    "anthropic": "anthropic-ai"
+    "anthropic": "anthropic-ai",
 }
