@@ -3,4 +3,9 @@ Init file for integrations module
 """
 
 from .burr_bridge import BurrBridge
-from .indexify_node import IndexifyNode
\ No newline at end of file
+from .indexify_node import IndexifyNode
+
+__all__ = [
+    "BurrBridge",
+    "IndexifyNode",
+]
