@@ -1,16 +1,17 @@
-""" 
-BaseNode Module
+"""
+This module defines the base node class for the ScrapeGraphAI application.
 """
 
 import re
 from abc import ABC, abstractmethod
 from typing import List, Optional
+
 from ..utils import get_logger
 
 
 class BaseNode(ABC):
     """
-    An abstract base class for nodes in a graph-based workflow, 
+    An abstract base class for nodes in a graph-based workflow,
     designed to perform specific actions when executed.
 
     Attributes:
@@ -27,7 +28,8 @@ class BaseNode(ABC):
         input (str): Expression defining the input keys needed from the state.
         output (List[str]): List of output keys to be updated in the state.
         min_input_len (int, optional): Minimum required number of input keys; defaults to 1.
-        node_config (Optional[dict], optional): Additional configuration for the node; defaults to None.
+        node_config (Optional[dict], optional): Additional configuration
+                                                for the node; defaults to None.
 
     Raises:
         ValueError: If `node_type` is not one of the allowed types.
@@ -52,7 +54,6 @@ class BaseNode(ABC):
         min_input_len: int = 1,
         node_config: Optional[dict] = None,
     ):
-
         self.node_name = node_name
         self.input = input
         self.output = output
@@ -86,7 +87,7 @@ class BaseNode(ABC):
 
         Args:
             param (dict): The dictionary to update node_config with.
-            overwrite (bool): Flag indicating if the values of node_config 
+            overwrite (bool): Flag indicating if the values of node_config
             should be overwritten if their value is not None.
         """
         for key, val in params.items():
@@ -134,7 +135,7 @@ class BaseNode(ABC):
 
     def _parse_input_keys(self, state: dict, expression: str) -> List[str]:
         """
-        Parses the input keys expression to extract 
+        Parses the input keys expression to extract
         relevant keys from the state based on logical conditions.
         The expression can contain AND (&), OR (|), and parentheses to group conditions.
 
@@ -149,11 +150,9 @@ class BaseNode(ABC):
             ValueError: If the expression is invalid or if no state keys match the expression.
         """
 
-        # Check for empty expression
         if not expression:
             raise ValueError("Empty expression.")
 
-        # Check for adjacent state keys without an operator between them
         pattern = (
             r"\b("
             + "|".join(re.escape(key) for key in state.keys())
@@ -166,10 +165,8 @@ class BaseNode(ABC):
                 "Adjacent state keys found without an operator between them."
             )
 
-        # Remove spaces
         expression = expression.replace(" ", "")
 
-        # Check for operators with empty adjacent tokens or at the start/end
         if (
             expression[0] in "&|"
             or expression[-1] in "&|"
@@ -180,7 +177,6 @@ class BaseNode(ABC):
         ):
             raise ValueError("Invalid operator usage.")
 
-        # Check for balanced parentheses and valid operator placement
         open_parentheses = close_parentheses = 0
         for i, char in enumerate(expression):
             if char == "(":
@@ -193,18 +189,13 @@ class BaseNode(ABC):
                     "Invalid operator placement: operators cannot be adjacent."
                 )
 
-        # Check for missing or balanced parentheses
         if open_parentheses != close_parentheses:
             raise ValueError("Missing or unbalanced parentheses in expression.")
 
-        # Helper function to evaluate an expression without parentheses
         def evaluate_simple_expression(exp: str) -> List[str]:
             """Evaluate an expression without parentheses."""
 
-            # Split the expression by the OR operator and process each segment
             for or_segment in exp.split("|"):
-
-                # Check if all elements in an AND segment are in state
                 and_segment = or_segment.split("&")
                 if all(elem.strip() in state for elem in and_segment):
                     return [
@@ -212,7 +203,6 @@ class BaseNode(ABC):
                     ]
             return []
 
-        # Helper function to evaluate expressions with parentheses
         def evaluate_expression(expression: str) -> List[str]:
             """Evaluate an expression with parentheses."""
 
@@ -221,10 +211,8 @@ class BaseNode(ABC):
                 end = expression.find(")", start)
                 sub_exp = expression[start + 1 : end]
 
-                # Replace the evaluated part with a placeholder and then evaluate it
                 sub_result = evaluate_simple_expression(sub_exp)
 
-                # For simplicity in handling, join sub-results with OR to reprocess them later
                 expression = (
                     expression[:start] + "|".join(sub_result) + expression[end + 1 :]
                 )
@@ -233,9 +221,12 @@ class BaseNode(ABC):
         result = evaluate_expression(expression)
 
         if not result:
-            raise ValueError(f"No state keys matched the expression. Expression was {expression}. State contains keys: {', '.join(state.keys())}")
+            raise ValueError(
+                f"""No state keys matched the expression.
+                             Expression was {expression}.
+                             State contains keys: {", ".join(state.keys())}"""
+            )
 
-        # Remove redundant state keys from the result, without changing their order
         final_result = []
         for key in result:
             if key not in final_result:
