@@ -1,19 +1,21 @@
-""""
+"""
 FetchNode Module
 """
+
 import json
 from typing import List, Optional
-from langchain_openai import ChatOpenAI, AzureChatOpenAI
-import pandas as pd
+
 import requests
 from langchain_community.document_loaders import PyPDFLoader
 from langchain_core.documents import Document
-from ..utils.cleanup_html import cleanup_html
+from langchain_openai import AzureChatOpenAI, ChatOpenAI
+
 from ..docloaders import ChromiumLoader
+from ..utils.cleanup_html import cleanup_html
 from ..utils.convert_to_md import convert_to_md
-from ..utils.logging import get_logger
 from .base_node import BaseNode
 
+
 class FetchNode(BaseNode):
     """
     A node responsible for fetching the HTML content of a specified URL and updating
@@ -55,54 +57,44 @@ class FetchNode(BaseNode):
         self.loader_kwargs = (
             {} if node_config is None else node_config.get("loader_kwargs", {})
         )
-        self.llm_model = (
-            {} if node_config is None else node_config.get("llm_model", {})
-        )
-        self.force = (
-            False if node_config is None else node_config.get("force", False)
-        )
+        self.llm_model = {} if node_config is None else node_config.get("llm_model", {})
+        self.force = False if node_config is None else node_config.get("force", False)
         self.script_creator = (
             False if node_config is None else node_config.get("script_creator", False)
         )
         self.openai_md_enabled = (
-            False if node_config is None else node_config.get("openai_md_enabled", False)
+            False
+            if node_config is None
+            else node_config.get("openai_md_enabled", False)
         )
 
-        self.cut = (
-            False if node_config is None else node_config.get("cut", True)
-        )
+        self.cut = False if node_config is None else node_config.get("cut", True)
 
         self.browser_base = (
             None if node_config is None else node_config.get("browser_base", None)
         )
 
+        self.scrape_do = (
+            None if node_config is None else node_config.get("scrape_do", None)
+        )
+
+        self.storage_state = (
+            None if node_config is None else node_config.get("storage_state", None)
+        )
+
     def execute(self, state):
         """
         Executes the node's logic to fetch HTML content from a specified URL and
         update the state with this content.
-
-        Args:
-            state (dict): The current state of the graph. The input keys will be used
-                            to fetch the correct data types from the state.
-
-        Returns:
-            dict: The updated state with a new output key containing the fetched HTML content.
-
-        Raises:
-            KeyError: If the input key is not found in the state, indicating that the
-                    necessary information to perform the operation is missing.
         """
-
         self.logger.info(f"--- Executing {self.node_name} Node ---")
 
-        # Interpret input keys based on the provided input expression
         input_keys = self.get_input_keys(state)
-        # Fetching data from the state based on the input keys
         input_data = [state[key] for key in input_keys]
 
         source = input_data[0]
         input_type = input_keys[0]
-        
+
         handlers = {
             "json_dir": self.handle_directory,
             "xml_dir": self.handle_directory,
@@ -118,12 +110,12 @@ class FetchNode(BaseNode):
 
         if input_type in handlers:
             return handlers[input_type](state, input_type, source)
-        elif self.input == "pdf_dir":
-            return state
-        elif not source.startswith("http"):
+        elif input_type == "local_dir":
             return self.handle_local_source(state, source)
-        else:
+        elif input_type == "url":
             return self.handle_web_source(state, source)
+        else:
+            raise ValueError(f"Invalid input type: {input_type}")
 
     def handle_directory(self, state, input_type, source):
         """
@@ -138,9 +130,7 @@ class FetchNode(BaseNode):
         dict: The updated state with the compressed document.
         """
 
-        compressed_document = [
-            source
-        ]
+        compressed_document = [source]
         state.update({self.output[0]: compressed_document})
         return state
 
@@ -166,7 +156,9 @@ class FetchNode(BaseNode):
 
         compressed_document = self.load_file_content(source, input_type)
 
-        return self.update_state(state, compressed_document)
+        # return self.update_state(state, compressed_document)
+        state.update({self.output[0]: compressed_document})
+        return state
 
     def load_file_content(self, source, input_type):
         """
@@ -184,10 +176,24 @@ class FetchNode(BaseNode):
             loader = PyPDFLoader(source)
             return loader.load()
         elif input_type == "csv":
-            return [Document(page_content=str(pd.read_csv(source)), metadata={"source": "csv"})]
+            try:
+                import pandas as pd
+            except ImportError:
+                raise ImportError(
+                    "pandas is not installed. Please install it using `pip install pandas`."
+                )
+            return [
+                Document(
+                    page_content=str(pd.read_csv(source)), metadata={"source": "csv"}
+                )
+            ]
         elif input_type == "json":
             with open(source, encoding="utf-8") as f:
-                return [Document(page_content=str(json.load(f)), metadata={"source": "json"})]
+                return [
+                    Document(
+                        page_content=str(json.load(f)), metadata={"source": "json"}
+                    )
+                ]
         elif input_type == "xml" or input_type == "md":
             with open(source, "r", encoding="utf-8") as f:
                 data = f.read()
@@ -215,7 +221,15 @@ class FetchNode(BaseNode):
 
         parsed_content = source
 
-        if (isinstance(self.llm_model, ChatOpenAI) or isinstance(self.llm_model, AzureChatOpenAI)) and not self.script_creator or self.force and not self.script_creator:
+        if (
+            (
+                isinstance(self.llm_model, ChatOpenAI)
+                or isinstance(self.llm_model, AzureChatOpenAI)
+            )
+            and not self.script_creator
+            or self.force
+            and not self.script_creator
+        ):
             parsed_content = convert_to_md(source)
         else:
             parsed_content = source
@@ -224,11 +238,13 @@ class FetchNode(BaseNode):
             Document(page_content=parsed_content, metadata={"source": "local_dir"})
         ]
 
-        return self.update_state(state, compressed_document)
+        # return self.update_state(state, compressed_document)
+        state.update({self.output[0]: compressed_document})
+        return state
 
     def handle_web_source(self, state, source):
         """
-        Handles the web source by fetching HTML content from a URL, 
+        Handles the web source by fetching HTML content from a URL,
         optionally converting it to Markdown, and updating the state.
 
         Parameters:
@@ -252,8 +268,11 @@ class FetchNode(BaseNode):
                 if not self.cut:
                     parsed_content = cleanup_html(response, source)
 
-                if  ((isinstance(self.llm_model, ChatOpenAI) or isinstance(self.llm_model, AzureChatOpenAI))
-                     and not self.script_creator) or (self.force and not self.script_creator):
+                if (
+                    isinstance(self.llm_model, (ChatOpenAI, AzureChatOpenAI))
+                    and not self.script_creator
+                    or (self.force and not self.script_creator)
+                ):
                     parsed_content = convert_to_md(source, parsed_content)
 
                 compressed_document = [Document(page_content=parsed_content)]
@@ -264,49 +283,83 @@ class FetchNode(BaseNode):
         else:
             loader_kwargs = {}
 
-            if self.node_config is not None:
+            if self.node_config:
                 loader_kwargs = self.node_config.get("loader_kwargs", {})
 
-            if self.browser_base is not None:
+            if self.browser_base:
                 try:
                     from ..docloaders.browser_base import browser_base_fetch
                 except ImportError:
-                    raise ImportError("The browserbase module is not installed. Please install it using `pip install browserbase`.")
+                    raise ImportError(
+                        """The browserbase module is not installed.
+                                      Please install it using `pip install browserbase`."""
+                    )
 
-                data =  browser_base_fetch(self.browser_base.get("api_key"),
-                                            self.browser_base.get("project_id"), [source])
+                data = browser_base_fetch(
+                    self.browser_base.get("api_key"),
+                    self.browser_base.get("project_id"),
+                    [source],
+                )
 
-                document = [Document(page_content=content,
-                                    metadata={"source": source}) for content in data]
+                document = [
+                    Document(page_content=content, metadata={"source": source})
+                    for content in data
+                ]
+            elif self.scrape_do:
+                from ..docloaders.scrape_do import scrape_do_fetch
+
+                if (
+                    (self.scrape_do.get("use_proxy") is None)
+                    or self.scrape_do.get("geoCode") is None
+                    or self.scrape_do.get("super_proxy") is None
+                ):
+                    data = scrape_do_fetch(self.scrape_do.get("api_key"), source)
+                else:
+                    data = scrape_do_fetch(
+                        self.scrape_do.get("api_key"),
+                        source,
+                        self.scrape_do.get("use_proxy"),
+                        self.scrape_do.get("geoCode"),
+                        self.scrape_do.get("super_proxy"),
+                    )
+
+                document = [Document(page_content=data, metadata={"source": source})]
             else:
-                loader = ChromiumLoader([source], headless=self.headless, **loader_kwargs)
+                loader = ChromiumLoader(
+                    [source],
+                    headless=self.headless,
+                    storage_state=self.storage_state,
+                    **loader_kwargs,
+                )
                 document = loader.load()
 
             if not document or not document[0].page_content.strip():
-                raise ValueError("No HTML body content found in the document fetched by ChromiumLoader.")
+                raise ValueError(
+                    """No HTML body content found in
+                                 the document fetched by ChromiumLoader."""
+                )
+
             parsed_content = document[0].page_content
 
-            if (isinstance(self.llm_model, ChatOpenAI) or isinstance(self.llm_model, AzureChatOpenAI))  and not self.script_creator or self.force and not self.script_creator and not self.openai_md_enabled:
+            if (
+                (
+                    isinstance(self.llm_model, ChatOpenAI)
+                    or isinstance(self.llm_model, AzureChatOpenAI)
+                )
+                and not self.script_creator
+                or self.force
+                and not self.script_creator
+                and not self.openai_md_enabled
+            ):
                 parsed_content = convert_to_md(document[0].page_content, parsed_content)
 
             compressed_document = [
                 Document(page_content=parsed_content, metadata={"source": "html file"})
             ]
-        
-        return self.update_state(state, compressed_document)
-
-    def update_state(self, state, compressed_document):
-        """
-        Updates the state with the output data from the node.
-
-        Args:
-            state (dict): The current state of the graph.
-            compressed_document (List[Document]): The compressed document content fetched
-                                                    by the node.
-
-        Returns:
-            dict: The updated state with the output data.
-        """
-
-        state.update({self.output[0]: compressed_document,})
+        state["doc"] = document
+        state.update(
+            {
+                self.output[0]: compressed_document,
+            }
+        )
         return state
