@@ -3,14 +3,21 @@ Module for generating the answer node
 """
 
 from typing import List, Optional
+
 from langchain.prompts import PromptTemplate
 from langchain_core.output_parsers import JsonOutputParser
 from langchain_core.runnables import RunnableParallel
+from langchain_mistralai import ChatMistralAI
+from langchain_openai import ChatOpenAI
 from tqdm import tqdm
-from ..utils.logging import get_logger
+
+from ..prompts import TEMPLATE_CHUKS_CSV, TEMPLATE_MERGE_CSV, TEMPLATE_NO_CHUKS_CSV
+from ..utils.output_parser import (
+    get_pydantic_output_parser,
+    get_structured_output_parser,
+)
 from .base_node import BaseNode
-from ..prompts.generate_answer_node_csv_prompts import (TEMPLATE_CHUKS_CSV,
-                                                        TEMPLATE_NO_CHUKS_CSV, TEMPLATE_MERGE_CSV)
+
 
 class GenerateAnswerCSVNode(BaseNode):
     """
@@ -81,32 +88,38 @@ class GenerateAnswerCSVNode(BaseNode):
 
         self.logger.info(f"--- Executing {self.node_name} Node ---")
 
-        # Interpret input keys based on the provided input expression
         input_keys = self.get_input_keys(state)
 
-        # Fetching data from the state based on the input keys
         input_data = [state[key] for key in input_keys]
 
         user_prompt = input_data[0]
         doc = input_data[1]
 
-        # Initialize the output parser
         if self.node_config.get("schema", None) is not None:
-            output_parser = JsonOutputParser(pydantic_object=self.node_config["schema"])
+            if isinstance(self.llm_model, (ChatOpenAI, ChatMistralAI)):
+                self.llm_model = self.llm_model.with_structured_output(
+                    schema=self.node_config["schema"]
+                )  # json schema works only on specific models
+
+                output_parser = get_structured_output_parser(self.node_config["schema"])
+                format_instructions = "NA"
+            else:
+                output_parser = get_pydantic_output_parser(self.node_config["schema"])
+                format_instructions = output_parser.get_format_instructions()
+
         else:
             output_parser = JsonOutputParser()
+            format_instructions = output_parser.get_format_instructions()
 
         TEMPLATE_NO_CHUKS_CSV_PROMPT = TEMPLATE_NO_CHUKS_CSV
         TEMPLATE_CHUKS_CSV_PROMPT = TEMPLATE_CHUKS_CSV
-        TEMPLATE_MERGE_CSV_PROMPT  = TEMPLATE_MERGE_CSV
+        TEMPLATE_MERGE_CSV_PROMPT = TEMPLATE_MERGE_CSV
 
         if self.additional_info is not None:
             TEMPLATE_NO_CHUKS_CSV_PROMPT = self.additional_info + TEMPLATE_NO_CHUKS_CSV
             TEMPLATE_CHUKS_CSV_PROMPT = self.additional_info + TEMPLATE_CHUKS_CSV
             TEMPLATE_MERGE_CSV_PROMPT = self.additional_info + TEMPLATE_MERGE_CSV
 
-        format_instructions = output_parser.get_format_instructions()
-
         chains_dict = {}
 
         if len(doc) == 1:
@@ -119,7 +132,7 @@ class GenerateAnswerCSVNode(BaseNode):
                 },
             )
 
-            chain =  prompt | self.llm_model | output_parser
+            chain = prompt | self.llm_model | output_parser
             answer = chain.invoke({"question": user_prompt})
             state.update({self.output[0]: answer})
             return state
@@ -128,27 +141,27 @@ class GenerateAnswerCSVNode(BaseNode):
             tqdm(doc, desc="Processing chunks", disable=not self.verbose)
         ):
             prompt = PromptTemplate(
-                    template=TEMPLATE_CHUKS_CSV_PROMPT,
-                    input_variables=["question"],
-                    partial_variables={
-                        "context": chunk,
-                        "chunk_id": i + 1,
-                        "format_instructions": format_instructions,
-                    },
-                )
+                template=TEMPLATE_CHUKS_CSV_PROMPT,
+                input_variables=["question"],
+                partial_variables={
+                    "context": chunk,
+                    "chunk_id": i + 1,
+                    "format_instructions": format_instructions,
+                },
+            )
 
-            chain_name = f"chunk{i+1}"
+            chain_name = f"chunk{i + 1}"
             chains_dict[chain_name] = prompt | self.llm_model | output_parser
 
         async_runner = RunnableParallel(**chains_dict)
 
-        batch_results =  async_runner.invoke({"question": user_prompt})
+        batch_results = async_runner.invoke({"question": user_prompt})
 
         merge_prompt = PromptTemplate(
-                template = TEMPLATE_MERGE_CSV_PROMPT,
-                input_variables=["context", "question"],
-                partial_variables={"format_instructions": format_instructions},
-            )
+            template=TEMPLATE_MERGE_CSV_PROMPT,
+            input_variables=["context", "question"],
+            partial_variables={"format_instructions": format_instructions},
+        )
 
         merge_chain = merge_prompt | self.llm_model | output_parser
         answer = merge_chain.invoke({"context": batch_results, "question": user_prompt})
