@@ -1,12 +1,15 @@
 """
 GenerateAnswerFromImageNode Module
 """
-import base64
+
 import asyncio
+import base64
 from typing import List, Optional
+
 import aiohttp
+
 from .base_node import BaseNode
-from ..utils.logging import get_logger
+
 
 class GenerateAnswerFromImageNode(BaseNode):
     """
@@ -27,11 +30,11 @@ class GenerateAnswerFromImageNode(BaseNode):
         """
         async process image
         """
-        base64_image = base64.b64encode(image_data).decode('utf-8')
+        base64_image = base64.b64encode(image_data).decode("utf-8")
 
         headers = {
             "Content-Type": "application/json",
-            "Authorization": f"Bearer {api_key}"
+            "Authorization": f"Bearer {api_key}",
         }
 
         payload = {
@@ -40,50 +43,61 @@ class GenerateAnswerFromImageNode(BaseNode):
                 {
                     "role": "user",
                     "content": [
-                        {
-                            "type": "text",
-                            "text": user_prompt
-                        },
+                        {"type": "text", "text": user_prompt},
                         {
                             "type": "image_url",
                             "image_url": {
                                 "url": f"data:image/jpeg;base64,{base64_image}"
-                            }
-                        }
-                    ]
+                            },
+                        },
+                    ],
                 }
             ],
-            "max_tokens": 300
+            "max_tokens": 300,
         }
 
-        async with session.post("https://api.openai.com/v1/chat/completions",
-                                headers=headers, json=payload) as response:
+        async with session.post(
+            "https://api.openai.com/v1/chat/completions", headers=headers, json=payload
+        ) as response:
             result = await response.json()
-            return result.get('choices', [{}])[0].get('message', {}).get('content', 'No response')
+            return (
+                result.get("choices", [{}])[0]
+                .get("message", {})
+                .get("content", "No response")
+            )
 
     async def execute_async(self, state: dict) -> dict:
         """
-        Processes images from the state, generates answers, 
+        Processes images from the state, generates answers,
         consolidates the results, and updates the state asynchronously.
         """
         self.logger.info(f"--- Executing {self.node_name} Node ---")
 
-        images = state.get('screenshots', [])
+        images = state.get("screenshots", [])
         analyses = []
 
-        supported_models = ("gpt-4o", "gpt-4o-mini", "gpt-4-turbo")
+        supported_models = ("gpt-4o", "gpt-4o-mini", "gpt-4-turbo", "gpt-4")
 
-        if self.node_config["config"]["llm"]["model"] not in supported_models:
-            raise ValueError(f"""Model '{self.node_config['config']['llm']['model']}'
-                             is not supported. Supported models are: 
-                             {', '.join(supported_models)}.""")
+        if (
+            self.node_config["config"]["llm"]["model"].split("/")[-1]
+            not in supported_models
+        ):
+            raise ValueError(
+                f"""The model provided
+                             is not supported. Supported models are:
+                             {", ".join(supported_models)}."""
+            )
 
         api_key = self.node_config.get("config", {}).get("llm", {}).get("api_key", "")
 
         async with aiohttp.ClientSession() as session:
             tasks = [
-                self.process_image(session, api_key, image_data,
-                                   state.get("user_prompt", "Extract information from the image"))
+                self.process_image(
+                    session,
+                    api_key,
+                    image_data,
+                    state.get("user_prompt", "Extract information from the image"),
+                )
                 for image_data in images
             ]
 
@@ -91,9 +105,7 @@ class GenerateAnswerFromImageNode(BaseNode):
 
         consolidated_analysis = " ".join(analyses)
 
-        state['answer'] = {
-            "consolidated_analysis": consolidated_analysis
-        }
+        state["answer"] = {"consolidated_analysis": consolidated_analysis}
 
         return state
 
