@@ -1,14 +1,28 @@
 """
 GenerateAnswerNode Module
 """
+
 from typing import List, Optional
+
 from langchain.prompts import PromptTemplate
+from langchain_community.chat_models import ChatOllama
 from langchain_core.output_parsers import JsonOutputParser
 from langchain_core.runnables import RunnableParallel
+from langchain_mistralai import ChatMistralAI
+from langchain_openai import ChatOpenAI
 from tqdm import tqdm
-from langchain_community.chat_models import ChatOllama
+
+from ..prompts.generate_answer_node_omni_prompts import (
+    TEMPLATE_CHUNKS_OMNI,
+    TEMPLATE_MERGE_OMNI,
+    TEMPLATE_NO_CHUNKS_OMNI,
+)
+from ..utils.output_parser import (
+    get_pydantic_output_parser,
+    get_structured_output_parser,
+)
 from .base_node import BaseNode
-from ..prompts.generate_answer_node_omni_prompts import TEMPLATE_NO_CHUNKS_OMNI, TEMPLATE_CHUNKS_OMNI, TEMPLATE_MERGE_OMNI
+
 
 class GenerateAnswerOmniNode(BaseNode):
     """
@@ -39,7 +53,7 @@ class GenerateAnswerOmniNode(BaseNode):
 
         self.llm_model = node_config["llm_model"]
         if isinstance(node_config["llm_model"], ChatOllama):
-            self.llm_model.format="json"
+            self.llm_model.format = "json"
 
         self.verbose = (
             False if node_config is None else node_config.get("verbose", False)
@@ -66,32 +80,44 @@ class GenerateAnswerOmniNode(BaseNode):
 
         self.logger.info(f"--- Executing {self.node_name} Node ---")
 
-        # Interpret input keys based on the provided input expression
         input_keys = self.get_input_keys(state)
 
-        # Fetching data from the state based on the input keys
         input_data = [state[key] for key in input_keys]
 
         user_prompt = input_data[0]
         doc = input_data[1]
         imag_desc = input_data[2]
 
-        # Initialize the output parser
         if self.node_config.get("schema", None) is not None:
-            output_parser = JsonOutputParser(pydantic_object=self.node_config["schema"])
+            if isinstance(self.llm_model, (ChatOpenAI, ChatMistralAI)):
+                self.llm_model = self.llm_model.with_structured_output(
+                    schema=self.node_config["schema"]
+                )
+
+                output_parser = get_structured_output_parser(self.node_config["schema"])
+                format_instructions = "NA"
+            else:
+                output_parser = get_pydantic_output_parser(self.node_config["schema"])
+                format_instructions = output_parser.get_format_instructions()
+
         else:
             output_parser = JsonOutputParser()
+            format_instructions = output_parser.get_format_instructions()
+
         TEMPLATE_NO_CHUNKS_OMNI_prompt = TEMPLATE_NO_CHUNKS_OMNI
         TEMPLATE_CHUNKS_OMNI_prompt = TEMPLATE_CHUNKS_OMNI
-        TEMPLATE_MERGE_OMNI_prompt= TEMPLATE_MERGE_OMNI
+        TEMPLATE_MERGE_OMNI_prompt = TEMPLATE_MERGE_OMNI
 
         if self.additional_info is not None:
-            TEMPLATE_NO_CHUNKS_OMNI_prompt = self.additional_info + TEMPLATE_NO_CHUNKS_OMNI_prompt
-            TEMPLATE_CHUNKS_OMNI_prompt = self.additional_info + TEMPLATE_CHUNKS_OMNI_prompt
-            TEMPLATE_MERGE_OMNI_prompt = self.additional_info + TEMPLATE_MERGE_OMNI_prompt
-
-        format_instructions = output_parser.get_format_instructions()
-
+            TEMPLATE_NO_CHUNKS_OMNI_prompt = (
+                self.additional_info + TEMPLATE_NO_CHUNKS_OMNI_prompt
+            )
+            TEMPLATE_CHUNKS_OMNI_prompt = (
+                self.additional_info + TEMPLATE_CHUNKS_OMNI_prompt
+            )
+            TEMPLATE_MERGE_OMNI_prompt = (
+                self.additional_info + TEMPLATE_MERGE_OMNI_prompt
+            )
 
         chains_dict = {}
         if len(doc) == 1:
@@ -105,7 +131,7 @@ class GenerateAnswerOmniNode(BaseNode):
                 },
             )
 
-            chain =  prompt | self.llm_model | output_parser
+            chain = prompt | self.llm_model | output_parser
             answer = chain.invoke({"question": user_prompt})
 
             state.update({self.output[0]: answer})
@@ -115,28 +141,27 @@ class GenerateAnswerOmniNode(BaseNode):
             tqdm(doc, desc="Processing chunks", disable=not self.verbose)
         ):
             prompt = PromptTemplate(
-                    template=TEMPLATE_CHUNKS_OMNI_prompt,
-                    input_variables=["question"],
-                    partial_variables={
-                        "context": chunk,
-                        "chunk_id": i + 1,
-                        "format_instructions": format_instructions,
-                    },
-                )
+                template=TEMPLATE_CHUNKS_OMNI_prompt,
+                input_variables=["question"],
+                partial_variables={
+                    "context": chunk,
+                    "chunk_id": i + 1,
+                    "format_instructions": format_instructions,
+                },
+            )
 
-            # Dynamically name the chains based on their index
-            chain_name = f"chunk{i+1}"
+            chain_name = f"chunk{i + 1}"
             chains_dict[chain_name] = prompt | self.llm_model | output_parser
 
         async_runner = RunnableParallel(**chains_dict)
 
-        batch_results =  async_runner.invoke({"question": user_prompt})
+        batch_results = async_runner.invoke({"question": user_prompt})
 
         merge_prompt = PromptTemplate(
-                template = TEMPLATE_MERGE_OMNI_prompt,
-                input_variables=["context", "question"],
-                partial_variables={"format_instructions": format_instructions},
-            )
+            template=TEMPLATE_MERGE_OMNI_prompt,
+            input_variables=["context", "question"],
+            partial_variables={"format_instructions": format_instructions},
+        )
 
         merge_chain = merge_prompt | self.llm_model | output_parser
         answer = merge_chain.invoke({"context": batch_results, "question": user_prompt})
