@@ -1,12 +1,22 @@
 """
 MergeAnswersNode Module
 """
+
 from typing import List, Optional
+
 from langchain.prompts import PromptTemplate
+from langchain_community.chat_models import ChatOllama
 from langchain_core.output_parsers import JsonOutputParser
-from ..utils.logging import get_logger
-from .base_node import BaseNode
+from langchain_mistralai import ChatMistralAI
+from langchain_openai import ChatOpenAI
+
 from ..prompts import TEMPLATE_COMBINED
+from ..utils.output_parser import (
+    get_pydantic_output_parser,
+    get_structured_output_parser,
+)
+from .base_node import BaseNode
+
 
 class MergeAnswersNode(BaseNode):
     """
@@ -33,6 +43,13 @@ class MergeAnswersNode(BaseNode):
         super().__init__(node_name, "node", input, output, 2, node_config)
 
         self.llm_model = node_config["llm_model"]
+
+        if isinstance(self.llm_model, ChatOllama):
+            if self.node_config.get("schema", None) is None:
+                self.llm_model.format = "json"
+            else:
+                self.llm_model.format = self.node_config["schema"].model_json_schema()
+
         self.verbose = (
             False if node_config is None else node_config.get("verbose", False)
         )
@@ -65,14 +82,23 @@ class MergeAnswersNode(BaseNode):
 
         answers_str = ""
         for i, answer in enumerate(answers):
-            answers_str += f"CONTENT WEBSITE {i+1}: {answer}\n"
+            answers_str += f"CONTENT WEBSITE {i + 1}: {answer}\n"
 
         if self.node_config.get("schema", None) is not None:
-            output_parser = JsonOutputParser(pydantic_object=self.node_config["schema"])
+            if isinstance(self.llm_model, (ChatOpenAI, ChatMistralAI)):
+                self.llm_model = self.llm_model.with_structured_output(
+                    schema=self.node_config["schema"]
+                )  # json schema works only on specific models
+
+                output_parser = get_structured_output_parser(self.node_config["schema"])
+                format_instructions = "NA"
+            else:
+                output_parser = get_pydantic_output_parser(self.node_config["schema"])
+                format_instructions = output_parser.get_format_instructions()
+
         else:
             output_parser = JsonOutputParser()
-
-        format_instructions = output_parser.get_format_instructions()
+            format_instructions = output_parser.get_format_instructions()
 
         prompt_template = PromptTemplate(
             template=TEMPLATE_COMBINED,
@@ -86,5 +112,16 @@ class MergeAnswersNode(BaseNode):
         merge_chain = prompt_template | self.llm_model | output_parser
         answer = merge_chain.invoke({"user_prompt": user_prompt})
 
+        # Get the URLs from the state, ensuring we get the actual URLs used for scraping
+        urls = []
+        if "urls" in state:
+            urls = state["urls"]
+        elif "considered_urls" in state:
+            urls = state["considered_urls"]
+
+        # Only add sources if we actually have URLs
+        if urls:
+            answer["sources"] = urls
+
         state.update({self.output[0]: answer})
         return state
