@@ -1,14 +1,17 @@
 """
 SearchInternetNode Module
 """
+
 from typing import List, Optional
+
 from langchain.output_parsers import CommaSeparatedListOutputParser
 from langchain.prompts import PromptTemplate
 from langchain_community.chat_models import ChatOllama
-from ..utils.logging import get_logger
+
+from ..prompts import TEMPLATE_SEARCH_INTERNET
 from ..utils.research_web import search_on_web
 from .base_node import BaseNode
-from ..prompts import TEMPLATE_SEARCH_INTERNET
+
 
 class SearchInternetNode(BaseNode):
     """
@@ -41,7 +44,17 @@ class SearchInternetNode(BaseNode):
         self.verbose = (
             False if node_config is None else node_config.get("verbose", False)
         )
-        self.search_engine = node_config.get("search_engine", "google")
+        self.proxy = node_config.get("loader_kwargs", {}).get("proxy", None)
+        self.search_engine = (
+            node_config["search_engine"]
+            if node_config.get("search_engine")
+            else "duckduckgo"
+        )
+
+        self.serper_api_key = (
+            node_config["serper_api_key"] if node_config.get("serper_api_key") else None
+        )
+
         self.max_results = node_config.get("max_results", 3)
 
     def execute(self, state: dict) -> dict:
@@ -80,17 +93,22 @@ class SearchInternetNode(BaseNode):
 
         search_answer = search_prompt | self.llm_model | output_parser
 
-        if isinstance(self.llm_model, ChatOllama) and self.llm_model.format == 'json':
+        if isinstance(self.llm_model, ChatOllama) and self.llm_model.format == "json":
             self.llm_model.format = None
             search_query = search_answer.invoke({"user_prompt": user_prompt})[0]
-            self.llm_model.format = 'json'
+            self.llm_model.format = "json"
         else:
             search_query = search_answer.invoke({"user_prompt": user_prompt})[0]
 
         self.logger.info(f"Search Query: {search_query}")
 
-        answer = search_on_web(query=search_query, max_results=self.max_results,
-                               search_engine=self.search_engine)
+        answer = search_on_web(
+            query=search_query,
+            max_results=self.max_results,
+            search_engine=self.search_engine,
+            proxy=self.proxy,
+            serper_api_key=self.serper_api_key,
+        )
 
         if len(answer) == 0:
             raise ValueError("Zero results found for the search query.")
