@@ -1,17 +1,18 @@
 """
 SearchLinkNode Module
 """
-from typing import List, Optional
+
 import re
-from tqdm import tqdm
-from urllib.parse import urlparse, parse_qs
+from typing import List, Optional
+from urllib.parse import parse_qs, urlparse
+
 from langchain.prompts import PromptTemplate
 from langchain_core.output_parsers import JsonOutputParser
-from langchain_core.runnables import RunnableParallel
-from ..utils.logging import get_logger
-from .base_node import BaseNode
-from ..prompts import TEMPLATE_RELEVANT_LINKS
+from tqdm import tqdm
+
 from ..helpers import default_filters
+from ..prompts import TEMPLATE_RELEVANT_LINKS
+from .base_node import BaseNode
 
 
 class SearchLinkNode(BaseNode):
@@ -36,17 +37,16 @@ class SearchLinkNode(BaseNode):
         input: str,
         output: List[str],
         node_config: Optional[dict] = None,
-        node_name: str = "GenerateLinks",
+        node_name: str = "SearchLinks",
     ):
         super().__init__(node_name, "node", input, output, 1, node_config)
 
-        self.llm_model = node_config["llm_model"]
-
-        # Apply filters if filter_links is True or if filter_config is provided
         if node_config.get("filter_links", False) or "filter_config" in node_config:
-            # Merge provided filter config with default filter config for partial configuration
             provided_filter_config = node_config.get("filter_config", {})
-            self.filter_config = {**default_filters.filter_dict, **provided_filter_config}
+            self.filter_config = {
+                **default_filters.filter_dict,
+                **provided_filter_config,
+            }
             self.filter_links = True
         else:
             self.filter_config = None
@@ -56,7 +56,9 @@ class SearchLinkNode(BaseNode):
         self.seen_links = set()
 
     def _is_same_domain(self, url, domain):
-        if not self.filter_links or not self.filter_config.get("diff_domain_filter", True):
+        if not self.filter_links or not self.filter_config.get(
+            "diff_domain_filter", True
+        ):
             return True
         parsed_url = urlparse(url)
         parsed_domain = urlparse(domain)
@@ -76,18 +78,21 @@ class SearchLinkNode(BaseNode):
         parsed_url = urlparse(url)
         query_params = parse_qs(parsed_url.query)
 
-        return any(indicator in parsed_url.path.lower() or indicator in query_params for indicator in lang_indicators)
+        return any(
+            indicator in parsed_url.path.lower() or indicator in query_params
+            for indicator in lang_indicators
+        )
+
     def _is_potentially_irrelevant(self, url):
         if not self.filter_links:
-            return False  # Skip irrelevant URL filtering if filtering is not enabled
+            return False
 
         irrelevant_keywords = self.filter_config.get("irrelevant_keywords", [])
         return any(keyword in url.lower() for keyword in irrelevant_keywords)
 
-
     def execute(self, state: dict) -> dict:
         """
-        Filter out relevant links from the webpage that are relavant to prompt. 
+        Filter out relevant links from the webpage that are relavant to prompt.
         Out of the filtered links, also ensure that all links are navigable.
         Args:
             state (dict): The current state of the graph. The input keys will be used to fetch the
@@ -117,8 +122,6 @@ class SearchLinkNode(BaseNode):
             )
         ):
             try:
-
-                # Primary approach: Regular expression to extract links
                 links = re.findall(r'https?://[^\s"<>\]]+', str(chunk.page_content))
 
                 if not self.filter_links:
@@ -128,19 +131,19 @@ class SearchLinkNode(BaseNode):
                     self.seen_links.update(relevant_links)
                 else:
                     filtered_links = [
-                    link for link in links
-                    if self._is_same_domain(link, source_url)
-                    and not self._is_image_url(link)
-                    and not self._is_language_url(link)
-                    and not self._is_potentially_irrelevant(link)
-                    and link not in self.seen_links
+                        link
+                        for link in links
+                        if self._is_same_domain(link, source_url)
+                        and not self._is_image_url(link)
+                        and not self._is_language_url(link)
+                        and not self._is_potentially_irrelevant(link)
+                        and link not in self.seen_links
                     ]
                     filtered_links = list(set(filtered_links))
                     relevant_links += filtered_links
                     self.seen_links.update(relevant_links)
 
             except Exception as e:
-                # Fallback approach: Using the LLM to extract links
                 self.logger.error(f"Error extracting links: {e}. Falling back to LLM.")
 
                 merge_prompt = PromptTemplate(
@@ -148,9 +151,7 @@ class SearchLinkNode(BaseNode):
                     input_variables=["content", "user_prompt"],
                 )
                 merge_chain = merge_prompt | self.llm_model | output_parser
-                answer = merge_chain.invoke(
-                    {"content": chunk.page_content}
-                )
+                answer = merge_chain.invoke({"content": chunk.page_content})
                 relevant_links += answer
 
         state.update({self.output[0]: relevant_links})
