@@ -3,14 +3,16 @@ Module for testing the smart scraper class
 """
 
 import os
+
 import pytest
-import pandas as pd
 from dotenv import load_dotenv
+from pydantic import BaseModel
+
 from scrapegraphai.graphs import SmartScraperGraph
-from scrapegraphai.utils import prettify_exec_info
 
 load_dotenv()
 
+
 @pytest.fixture
 def graph_config():
     """Configuration of the graph"""
@@ -24,6 +26,7 @@ def graph_config():
         "headless": False,
     }
 
+
 def test_scraping_pipeline(graph_config):
     """Start of the scraping pipeline"""
     smart_scraper_graph = SmartScraperGraph(
@@ -35,7 +38,8 @@ def test_scraping_pipeline(graph_config):
     result = smart_scraper_graph.run()
 
     assert result is not None
-    assert isinstance(result, dict) 
+    assert isinstance(result, dict)
+
 
 def test_get_execution_info(graph_config):
     """Get the execution info"""
@@ -50,3 +54,27 @@ def test_get_execution_info(graph_config):
     graph_exec_info = smart_scraper_graph.get_execution_info()
 
     assert graph_exec_info is not None
+
+
+def test_get_execution_info_with_schema(graph_config):
+    """Get the execution info with schema"""
+
+    class ProjectSchema(BaseModel):
+        title: str
+        description: str
+
+    class ProjectListSchema(BaseModel):
+        projects: list[ProjectSchema]
+
+    smart_scraper_graph = SmartScraperGraph(
+        prompt="List me all the projects with their description.",
+        source="https://perinim.github.io/projects/",
+        config=graph_config,
+        schema=ProjectListSchema,
+    )
+
+    smart_scraper_graph.run()
+
+    graph_exec_info = smart_scraper_graph.get_execution_info()
+
+    assert graph_exec_info is not None
